==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebSizeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescription } from "./WebSizeDescription";
/**
 * @hidden
 */
export let WebSizeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSizeDescriptionMetadata extends Base {
        static b(a) {
            if (WebSizeDescriptionMetadata.a == null) {
                WebSizeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSizeDescriptionMetadata.c(WebSizeDescriptionMetadata.a);
            }
            if (a.k(WebSizeDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSizeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Size");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebSizeDescriptionMetadata.b(a);
            a.ad("WebSize", () => new WebSizeDescription());
            a.ac("WebSize", WebSizeDescriptionMetadata.a);
        }
    }
    WebSizeDescriptionMetadata.$t = markType(WebSizeDescriptionMetadata, 'WebSizeDescriptionMetadata');
    WebSizeDescriptionMetadata.a = null;
    return WebSizeDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebSizeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescription } from "./WebSizeDescription";
/**
 * @hidden
 */
export let WebSizeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSizeDescriptionMetadata extends Base {
        static b(a) {
            if (WebSizeDescriptionMetadata.a == null) {
                WebSizeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSizeDescriptionMetadata.c(WebSizeDescriptionMetadata.a);
            }
            if (a.k(WebSizeDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSizeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Size");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebSizeDescriptionMetadata.b(a);
            a.ae("WebSize", () => new WebSizeDescription());
            a.ad("WebSize", WebSizeDescriptionMetadata.a);
        }
    }
    WebSizeDescriptionMetadata.$t = markType(WebSizeDescriptionMetadata, 'WebSizeDescriptionMetadata');
    WebSizeDescriptionMetadata.a = null;
    return WebSizeDescriptionMetadata;
})();
